@@ -17,6 +17,9 @@ from blueman.bluez.BlueZInterface import BlueZInterface
 from _blueman import rfcomm_list
 from blueman.services import SerialPort
 
+import gi
+gi.require_version("Gtk", "3.0")
+from gi.repository import Gtk
 
 def get_x_icon(icon_name, size):
     ic = get_icon(icon_name, size)
@@ -108,7 +111,7 @@ class ManagerDeviceMenu(Gtk.Menu):
         device = service.device
 
         def success(*args2):
-            dprint("success", args2)
+            dprint("success", " ".join(args2))
             prog.message(_("Success!"))
 
             if isinstance(service, SerialPort) and SERIAL_PORT_SVCLASS_ID == uuid128_to_uuid16(service.uuid):
@@ -194,7 +197,7 @@ class ManagerDeviceMenu(Gtk.Menu):
         op = self.get_op(device)
 
         if op != None:
-            item = create_menuitem(op, get_icon("network-transmit-recieve", 16))
+            item = create_menuitem(op, get_icon("network-transmit-receive", 16))
             item.props.sensitive = False
             item.show()
             self.append(item)
