@@ -13,8 +13,9 @@ if not os.path.exists('/dev/rfkill'):
     raise ImportError("Hardware kill switch not found")
 
 class RfKill(MechanismPlugin):
-    @dbus.service.method('org.blueman.Mechanism', in_signature="b", out_signature="")
-    def SetRfkillState(self, state):
+    @dbus.service.method('org.blueman.Mechanism', in_signature="b", out_signature="", sender_keyword="caller")
+    def SetRfkillState(self, state, caller):
+        self.confirm_authorization(caller, "org.blueman.rfkill.setstate")
         f = open('/dev/rfkill', 'r+b', buffering=0)
         f.write(struct.pack("IBBBB", 0, RFKILL_TYPE_BLUETOOTH, RFKILL_OP_CHANGE_ALL, (0 if state else 1), 0))
         f.close()
